#
# spec file for package python-abimap
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-abimap
Version:        0.3.2
Release:        3.15
Summary:        A helper for library maintainers to use symbol versioning
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/ansasaki/abimap
Source:         https://files.pythonhosted.org/packages/source/a/abimap/abimap-%{version}.tar.gz
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pytest-console-scripts}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This script allows to generate and update symbol version linker scripts which
adds version information to the exported symbols. The script is intended to be
integrated as part of a shared library build to check for changes in the set of
exported symbols and update the symbol version linker script accordingly.

%package doc
Summary:        Symbol versioning helper (Documentation)
Group:          Documentation/HTML

%description doc
Documentation for the symbol versioning helper %{name}

%prep
%setup -q -n abimap-%{version}
# https://github.com/ansasaki/abimap/issues/87
sed -i 's:pytest-runner::' setup.py

%build
%python_build

PYTHONPATH=${PWD}/src:${PWD}/tests sphinx-build docs html
PYTHONPATH=${PWD}/src:${PWD}/tests sphinx-build -E -b man docs man

%install
%python_install

rm -rf html/.{doctrees,buildinfo}

install -d -m 0755 %{buildroot}%{_mandir}/man1
install -m 0644 man/abimap.1 %{buildroot}%{_mandir}/man1/

%python_clone -a %{buildroot}%{_mandir}/man1/abimap.1
%python_clone -a %{buildroot}%{_bindir}/abimap

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%make_build -j1 -C tests ABIMAP_NAME_VERSION="abimap-%{version}" ABIMAP_VERSION="%{version}"
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib}:${PWD}/tests py.test-%{$python_version} -vv tests -k 'not test_main'

%post
%python_install_alternative abimap abimap.1

%postun
%python_uninstall_alternative abimap

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/abimap
%python_alternative %{_mandir}/man1/abimap.1%{?ext_man}
%{python_sitelib}/*

%files %{python_files doc}
%doc html
%license LICENSE

%changelog
* Thu Dec  9 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Aug 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop no longer needed abimap-0.3.0-disable-pytest-console-script-tests.patch
  and properly depend on pytest-console-scripts
* Thu Aug 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.2:
  * Fixed broken builds due to changes in warning output
  * Changed tests to check error messages
  * Added python 3.7 to testing matrix
  * Added requirement to verify SNI when checking URLs in docs
* Mon Aug 20 2018 tchvatal@suse.com
- Just require python-setuptools not use macros as it gets auto-expanded
  by lua parser properly
* Mon Aug 20 2018 asn@cryptomilk.org
- Update to version 0.3.1
  * Fixed bug when sorting releases: the older come first
  * Added missing runtime requirement for setuptools
  * Added manpage generation
* Wed Aug  8 2018 asn@cryptomilk.org
- Add missing Requires for python-setuptools
- Remove noarch from doc (the whole package is noarch)
- Remove unneeded build require on python-devel
* Fri Aug  3 2018 asn@cryptomilk.org
- Initial package
- Add abimap-0.3.0-disable-pytest-console-script-tests.patch
  * We need to disable the pytest-console-script tests temporarily. The package
    can't be built yet as the tests are not working. The upstream maintainer of
    pytest-console-script is aware.
